<?php


/* Default Site Title Color */
function zeitfresser_get_default_site_title_color() {
    return "#f7f7fa";
}

/* Default Primary Color */
function zeitfresser_get_default_primary_color() {
    return "#f7f7fa";
}

/* Default Secondary Color */
function zeitfresser_get_default_secondary_color() {
    return "#f7f7fa";
}

/* Default Light Color */
function zeitfresser_get_default_light_color() {
    return "#1e1f29";
}

/* Default Grey Color */
function zeitfresser_get_default_grey_color() {
    return "#f7f7fa";
}

/* Default Dark Color */
function zeitfresser_get_default_dark_color() {
    return "#f7f7fa";
}

/* Default Background Color */
function zeitfresser_get_default_background_color() {
    return "1e1f29";
}